@@ -81,7 +81,8 @@ class Trie(object):
                 sub_trie = self._children[first]
             else:
                 sub_trie = Trie(
-                    default=self._default, path_constructor=self._path_constructor
+                    default=self._default,
+                    path_constructor=self._path_constructor,
                 )
                 self._children[first] = sub_trie
 
